affine
======

.. automodule:: affine

   
   .. rubric:: Module Attributes

   .. autosummary::
   
      identity
   
   .. rubric:: Functions

   .. autosummary::
   
      cos_sin_deg
      dumpsw
      loadsw
   
   .. rubric:: Classes

   .. autosummary::
   
      Affine
   
   .. rubric:: Exceptions

   .. autosummary::
   
      AffineError
      TransformNotInvertibleError
      UndefinedRotationError
   